---
title: "Contractarian Free Speech"
author: "Alan Haworth"
image: img/alan-haworth.jpg
era: "Twentieth Century"
topic: "Free Speech"
draft: false
---

*The following excerpt is from, [“Free Speech”](https://www.amazon.co.uk/Free-Speech-Problems-Philosophy-Haworth/dp/0415148057/ref=sr_1_1?s=books&ie=UTF8&qid=1545954721&sr=1-1&keywords=free+speech+routledge+haworth), by Alan Haworth*

**Free Speech From The Contract**

[Given John Rawls’ rational choice theory, and the veil of ignorance thought experiment, from *A Theory of Justice*]… we are… faced with the following question: would a group of rational choosers, who are constrained to coexist and who are negotiating from the standpoint of an appropriately constructed original position, include a free speech principle amongst the fundamental elements of their constitution? I shall argue that, for all contractualism’s initial promise, an attempt to construct a contractualist defence of free speech must ultimately fail because it requires making too many ad hoc presuppositions*…*



FREE SPEECH AS A ‘BASIC LIBERTY’

Unlike Mill’s On Liberty, which contains a whole chapter devoted entirely to the defence of {{< reltab title="‘the liberty of thought and discussion’," url="/reading/on-liberty-of-thought-and-discussion/" >}} Rawls’s *A Theory of Justice* offers no independent defence of free speech per se. Instead, free speech is treated as one item in a package of ‘basic liberties’. These are listed by Rawls as,

> *roughly speaking, political liberty (the right to vote and to be eligible for public office) together with freedom of speech and assembly; liberty of conscience and freedom of thought; freedom of the person along with the right to hold (personal) property; and freedom from arbitrary arrest and seizure as defined by the concept of the rule of law. These liberties are all required to be equal by the first principle, since citizens of a just society are to have the same basic rights.*
>
> (Rawls 1972:61)

From our perspective, the passage’s most striking feature is that Rawls’s list actually contains two distinct items, each of which might reasonably be included in the category ‘free speech’ on purely first-glance grounds. One is the freedom Rawls explicitly calls ‘freedom of speech’. Note that this is placed, without reservation, in the same class as ‘political liberty (the right to vote and to be eligible for public office)’ and freedom of assembly. So, here Rawls is making a direct connection between free speech and the democratic decision-making system. The other basic liberty is a liberty also defended by Mill, namely ‘freedom of thought’. Note that this latter freedom is classified together with ‘freedom of conscience’ and—further—that ‘freedom of conscience’ is defined by Rawls as ‘religious and moral freedom’ or the freedom to honour one’s ‘religious or moral obligations’ (ibid.:206).

Rawls’s idea that there is a package of basic liberties clearly raises the question why treat those liberties as basic—the ones on the list—and not some other set? In answer, Rawls offers an argument for ‘liberty of conscience’ which, or so he claims, ‘can be generalised to other freedoms, although not always with the same force’ (ibid.). So here is another striking point: although Rawls lists a number of basic liberties, his rationale for including them on the list is founded on a single argument. That argument runs as follows: first, Rawls imagines his rational choosers having to decide ‘which principle they should adopt to regulate the liberties of citizens in regard to their fundamental, religious, moral, and philosophical interests’. He then writes,

> Now it seems that equal liberty of conscience is the only principle that the persons in the original position can acknowledge. They cannot take chances with their liberty by permitting the dominant religious or moral doctrine to persecute or to suppress others if it wishes. Even granted (what may be questioned) that it is more probable than not that one will turn out to belong to the majority (if a majority exists) to gamble in this way would show that one did not take one’s religious or moral convictions seriously, or highly value the liberty to examine one’s beliefs. Nor on the other hand, could the parties consent to the principle of utility. In this case their freedom would be subject to the calculus of social interests and they would be authorising its restriction if this would lead to a greater net balance of satisfaction.
>
> (Ibid.:207)

There are two observations on the general character of Rawls’s procedure to be made here. The first is that it is unsurprising that Rawls should rely so heavily on an argument which centres upon people’s unwillingness to ‘take chances’, for it forcibly reflects his contractualist scenario with the latter’s emphasis on the necessity for cooperation. The point is this: whatever cooperation’s advantages may be, it is more than likely that there will be some things which are so important to you that you will not be prepared to abandon them under any circumstances. That is just plain common sense. Your confidential diaries, your toothbrush; these are things you will want to secure in a locker marked ‘personal’. As for your ‘religious or moral convictions’, even your diaries and your toothbrush must pale into insignificance besides these. If they don’t then, as Rawls remarks, your convictions can’t be serious.

The second observation is that Rawls is following some traditional routes. He is by no means the first to connect freedom of speech with the democratic process. Nor is he alone in modelling free speech on the liberty of conscience. Mill does much the same, as we have seen. At least, he does in the sense that his ‘classic’ case for the liberty of thought and discussion began life, in earlier hands (such as Milton’s), as an argument for religious toleration. To generalise, there is no doubt that the earlier debate over toleration in religion is the direct ancestor of the modern argument about free speech, or that it was in the later half of the seventeenth century that the former began to mutate into the latter; (just as On Liberty can claim an ancestor in {{< reltab title="Milton’s Areopagitica," url="/reading/areopagitica/" >}} so can Rawls’s argument for freedom of speech and liberty of conscience in {{< reltab title="Locke’s A Letter Concerning Toleration" url="/reading/locke-on-toleration-of-religious-difference" >}})…. So, by according conceptual priority to liberty of conscience Rawls’s argument carries a certain echo of the historical sequence…

FREE SPEECH AND LIBERTY OF CONSCIENCE

…‘Liberty of conscience’ is Rawls’s phrase for the liberty to express deeply held beliefs, especially religious beliefs (including atheism). It is, thus, roughly equivalent to the freedom more usually referred to as ‘religious liberty’. This raises the question is liberty of conscience a good model for free speech? There are some good reasons for thinking that it is not, and I shall mention three.

The first is that although language frequently plays a crucial role within the context of religion and religious practice it is not a role from which one can generalise to other areas in which language figures. For an obvious case in point, take prayer—talking to God or some other supernatural being. Prayer is crucial to much religious practice, but so far as I can see it is not an activity from which one can generalise to other uses of language, particularly those uses which one might conceivably want to protect with a free speech principle. It is worth recalling some of the features which, as I pointed out some time ago, characteristically tend to distinguish religious belief from other forms of belief. There is, first, the fact that a religious belief tends to be more or less exclusive to a specific identifiable group—the Muslims, the Christians, the Southern Baptists—and, second, there is the fact that, in order to hold it, it tends to be the case that you must also hold other, related, beliefs which are also exclusive to the groups. It is this which distinguishes a religious belief from, say, a scientific belief. The latter is related to other beliefs, standards of proof, and so on, which are more diffusely spread…. It seems that features typical of religious belief are atypical of beliefs in general. This casts doubt on the possibility of generalising from a defence of the liberty to hold and express them to all beliefs.

The second reason for thinking that liberty of conscience is not a good model for free speech is that—again characteristically and on the whole—a religion is more than just a belief system. In religion, the belief system is—typically—just part of a complex to which participation in various forms of activity—including non-linguistic activity—is equally crucial. The periodic ritual, the pilgrimage, the observance of holy days and holy places, of fasts, all these can be constitutive of a religion too. To have a religion is, thus, quite usually, to have a certain way of life. Again, it is not obvious that an argument defending the right to exercise speech within the context of a way of life can be generalised to cover freedoms one might want to protect with a free speech principle. The point is related to my third reason for rejecting liberty of conscience as a model for free speech generally. This is that if Rawls has a good argument for religious tolerance in a world of diverse and conflicting belief it is because choosers strike a posture which is fundamentally defensive. (They want to protect those things with which they are not prepared to ‘take chances’.) (Rawls 1972:207). We should note that in this respect he is continuing a liberal tradition which is also exemplified by—for example—Mill’s famous ‘sphere of action’ passage. As you will recall, Mill wrote that ‘There is a sphere of action in which society, as distinguished from the individual, has if any, only an indirect interest’. And he went on to add that the sphere comprises, amongst other things, ‘liberty of conscience in the most comprehensive sense’ (Mill 1859:1, §12). Similarly, Rawls’s choosers erect a defensive palisade.

Now, the question is whether Rawls’s argument for liberty of conscience can be generalised to an argument for free speech. I don’t think it can. Consider the following example. An investigative journalist has come across information which will seriously compromise an important public figure. Suppose that he is challenged for a reason why he should be left free to publicise the material and to continue with his investigation and that—by analogy with Rawls’s argument—the reason he gives for being left unhindered is ‘because it is supremely important to me that I be left to get on with it’. Plainly, he has not offered a good justification for the freedom of the press to publish the results of investigative journalism. Quite the contrary; by equating his activities with self-expression he seems to have reduced their significance. Of course, it could be that, in the case of this journalist, his activities form an important part of his self-development, his self-expression, and so on—the same could be true for his religion—but all that is beside the point. In this sort of case it is right to expect a justification in terms of an activity’s public function, its relation to ‘the public interest’, for example; that is, not with an argument paralleling Rawls’s for liberty of conscience.

Or again, take intellectual activity in the pursuit of truth, as defended by Mill with his argument for ‘the liberty of thought and discussion’. In parallel with Rawls’s argument for the protection of ‘fundamental religious, moral, and philosophical interests’ one can —I suppose—portray this as a set of activities in which those who wish to should be left free to engage. However, if Mill is right, this would be to miss the point, because the point lies in the activity’s effects; that is, in the benefits it yields for humanity generally. Recall, too, that (as it transpired from our earlier discussion of Mill) Mill’s argument is not so much false as more limited in its range of application than it is often assumed to be. It is beginning to look as if something similar is true in Rawls’s case…

CONCLUSIONS

…Let us now take stock of the direction this argument is taking… the flaws I have identified in Rawls’s argument are not specific to Rawls’s first book. On the contrary, they have their sources in features of the contractualist stance itself. Any contractualist derivation of a right to free speech must encounter parallel difficulties, and *A Theory of Justice* provides just one illustration of how they arise…

…consider the feature to which I have just been referring, that Rawls’s choosers negotiate from positions which are fundamentally defensive. This flows quite naturally from some basic contractualist assumptions. There are two, the first being that the choosers have differing plans, purposes, and value systems. This assumption is basic in the sense that new wave contractualism—Rawlsian and post-Rawlsian—derives much of its point from this assumption of an irreducible difference between individual ‘conceptions of the good’, with its logical consequence that the choosers will not automatically agree to some given set of principles, as they might in an Anarchist Utopia. The second basic assumption is that the choosers are not completely altruistic. From this it follows that every individual will want to make provision for those things he or she will want to protect whatever the preferences expressed by the others may be. As I put it earlier, there has to be a locker for you—one marked ‘personal’—ready to take such items as your toothbrush, your personal diary, and your ‘fundamental religious, moral, and philosophical interests’. To derive a right to free speech from these assumptions all you need to add is an argument to show how that right serves to defend whatever it is you want to put in the locker. It follows—as a first conclusion—that any contractualist derivation of free speech—not just Rawls’s —must prioritise that liberty’s defensive functions and relegate others to the background….

…it is true enough that there has to be some relationship of representation between the hypothetical rational choosers in their hypothetical situation and ourselves in our own. (I have already argued the point at some length.) However, there must also be differences. If there were none, there would be no point in telling the hypothetical story. You might just as well cut it out and concentrate on what real people would (or should) choose in a real situation. In the argument of *A Theory of Justice*, the difference is one of perspective and it results, in turn, from ignorance on the part of the choosers. As Rawls insists, ‘No one knows his place in society, his class position or social status; nor does he know his fortune in the distribution of natural assets and abilities, his intelligence and strength’ …and so on (Rawls 1972:137). The imposition of this ‘veil of ignorance’ is meant to ensure that the parties ‘evaluate principles solely on the basis of general considerations’ (ibid.). According to Rawls they must if his argument is to mirror the main contours of the concept of justice, and—as I am sure is very well known—it is from behind it that they select his two basic principles.

Now, the problem I am thinking of arises because complete ignorance makes any sort of choice impossible. Suppose you are told that you have a choice between two alternatives, A and B, but that you are given no further information. All you know is that A and B are there to be chosen between. In such a situation, it is obvious that no real choice is possible. At the very least you need to know what sorts of things A and B are—varieties of pizza, election candidates, principles of justice—and, depending on the example, it is very likely that you will need to know more than that. It follows that, however hypothetical a ‘contract’ story may be, some knowledge must be built in to the argument. Sure enough, in his derivation of the two principles Rawls satisfies this requirement by granting his choosers a bare minimum of relevant information. Thus, although no one knows ‘his conception of the good, the particulars of his rational plan of life, or even the special features of his psychology such as his aversion to risk’ (ibid.), everyone knows that he or she will have some ‘rational plan of life’ and some sort of attitude to risk. Again, although ‘no one knows his place in society, his class position or social status’ (ibid.), everyone knows that he or she will occupy some place in society and, indeed, that there is a probability of finding himself or herself amongst the least advantaged. They are even granted knowledge of politics, economics, and psychology. Even so, this is not granting everything, and there is still theoretical work for ignorance to do. The choosers are not permitted to know ‘how the various alternatives will affect their own particular case’, and are consequently obliged to evaluate principles solely on the basis of general considerations’ (ibid.: 136– 7). Rawls’s claim that, ‘the theory of the good used in arguing for the principles of justice is restricted to the bare essentials’ (ibid.: 396) is, I think, perfectly credible.

But deriving principles which operate at a fairly high level of abstraction is one thing. It is not necessarily so easy to move from there to the more concrete and specific. As we have seen, that is what Rawls wants to do. In other words he wants to move from the derivation of his principles to the justification of a specifically liberal value system. This is instantiated by, for example, his argument for the basic liberties, ‘roughly speaking, political liberty (the right to vote and to be eligible for public office) together with freedom of speech and assembly; liberty of conscience and freedom of thought’, and the rest (ibid.: 61). I suggest that, where this sort of attempt to move from the relatively abstract to the relatively specific is made, two things are guaranteed to happen. The first is that the hypothetical ‘rational-choice’ scenario will lose its grip. This is bound to happen because there won’t usually be much by way of a strict analogy between the hypothetical scenario and the real-life contexts to which the specifically liberal value system is meant to apply. The latter will lack the former’s formalistic, game-like structure. We have seen this instantiated in Rawls’s attempt to use his ‘choice’ story to link freedom of speech with the democratic process. There, the hypothetical scenario drops the more out of account, the less the exercise of free speech is construed on the model of voting (which is, at least, a structured, game-like procedure). The second is that the real work will be done, instead, by an appeal to (actual or supposed) contingent fact. We have also seen this process at work in Rawls’s more ‘realistic’ arguments that free speech is a basic liberty; for example, in his argument that democracy requires free speech because it requires a ‘public forum’ (ibid.: 225). The rational choice element in the argument is, thus, increasingly sidelined.